'use strict';
var user = require('../services/userService.js');
const { body } = require('express-validator')

exports.validate = (method) => {

  switch (method) {
    case 'change_password': {
     return [
     body('new_password', 'New password is required.').not().isEmpty(),
     body('confirmed_password', 'Confirmed password is required.').not().isEmpty(),
     ]
   }

   case 'check_password': {
     return [
      body('password', 'Password is required.').not().isEmpty()
     ]
   }

   case 'upload': {
     return [
     body('loan_id', 'Loan id is required.').not().isEmpty()
     ]
   }

   case 'apply_loan': {
     return [
     body('loan_amount', 'Loan amount is required.').not().isEmpty(),
     body('loan_duration', 'Loan duration is required.').not().isEmpty(),
     body('loan_type', 'Loan type is required.').not().isEmpty()
     ]
   }
   case 'update_profile': {
     return [
     body('first_name', 'First name is required.').not().isEmpty().isAlpha(),
     body('last_name', 'Last name is required.').not().isEmpty().isAlpha(),
     body('longitude', 'Longitude is required.').not().isEmpty(),
     body('latitude', 'Latitude is required.').not().isEmpty(),
     body('state', 'State is required.').not().isEmpty(),
     body('country', 'Country is required.').not().isEmpty(),
     body('city', 'City is required.').not().isEmpty(),
     body('address', 'Address is required.').not().isEmpty(),
     body('date_of_birth', 'Date of birth is required.').not().isEmpty(),
     ]
   }

   case 'set-language': {
     return [
     body('language', 'Language is required.').not().isEmpty(),
     ]
   }

 }
}

const { validationResult } = require('express-validator');

exports.checkToken = function(req, res){
  //user.checkToken(req.headers.authorization,req.id,function(err, result){
    user.checkToken(req.headers.authorization,function(err, result){
      if (err)
        res.send(err);
      res.json(result);
    });
  };

  exports.get_user = function(req, res){
    user.get_user(req.headers.authorization,req.body.id,function(err, result){
      if (err)
        res.send(err);
      res.json(result);
    });
  };

  exports.create_lead = function(req, res){
    user.create_lead(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };

  exports.upload = function(req, res){
    const errors = validationResult(req);
    if (!errors.isEmpty()){
      res.status(200).json({  status:'error',errors: errors.array() });
      return;
    }
    user.upload(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };

  exports.applyLoan = function(req, res){
    const errors = validationResult(req);
    if (!errors.isEmpty()){
      res.status(200).json({  status:'error',errors: errors.array() });
      return;
    }
    user.applyLoan(req.headers.authorization,req.body,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };
  

  exports.update_user = function(req, res){
    user.update_user(req.headers.authorization,req.body,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };

  exports.upload_profile_pic = function(req, res){
    user.upload_profile_pic(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };
  

  exports.get_profile = function(req, res){
    user.get_profile(req.headers.authorization,req.body,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };
  
  

  exports.get_cms = function(req, res){
    user.get_cms(req.headers.authorization,req.body,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };

  exports.get_notification = function(req, res){
    user.get_notification(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
  };

  exports.set_language = function(req, res){
   const errors = validationResult(req);
   if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  user.set_language(req.headers.authorization,req.body,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};


exports.update_profile = function(req, res){
 const errors = validationResult(req);
 if (!errors.isEmpty()){
  res.status(200).json({  status:'error',errors: errors.array() });
  return;
}
user.update_profile(req.headers.authorization,req.body,function(err, result){
  if (err)
    res.send(err);
  res.json(result);
});
};

exports.get_language = function(req, res){
  user.get_language(req.headers.authorization,req.body,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};



exports.assigned_lead_list = function(req, res){
  user.assigned_lead_list(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.active_lead_list = function(req, res){
  user.active_lead_list(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.active_lead_list_filter = function(req, res){
  user.active_lead_list_filter(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.get_active_lead_data = function(req, res){
  user.get_active_lead_data(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.assigned_lead_list_filter = function(req, res){
  user.assigned_lead_list_filter(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.get_assigned_lead_data = function(req, res){
  user.get_assigned_lead_data(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.listLoan = function(req, res){
  user.listLoan(req.headers.authorization,req,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.loanManagement = function(req, res){
  user.loanManagement(req.body,function(err, result){
    //console.log(token)
    if (err)
      res.send(err);
    res.json(result);
  });
};



exports.change_password = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(422).json({ errors: errors.array() });
    return;
  }
  user.change_password(req.headers.authorization,req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.check_password = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(422).json({ errors: errors.array() });
    return;
  }
  user.check_password(req.headers.authorization,req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};